
----------------------------------------------------------------------------------------------------
-- TUTORIAL 1
----------------------------------------------------------------------------------------------------

-- Get Advanced Tiled Loader
local ATL = require("AdvTiledLoader") 

--  Set maps/ as the base directory for map loading
ATL.Loader.path = 'maps/'

-- Use the loader to load the map
local map = ATL.Loader.load("desert.tmx") 

-- Draw the map
function love.draw() map:draw() end

----------------------------------------------------------------------------------------------------
-- TUTORIAL 2
----------------------------------------------------------------------------------------------------

-- Define the translation
local tx, ty = 0, 0

-- Move the camera
function love.update(dt)
	if love.keyboard.isDown("up") then ty = ty + 250*dt end
	if love.keyboard.isDown("down") then ty = ty - 250*dt end
	if love.keyboard.isDown("left") then tx = tx + 250*dt end
	if love.keyboard.isDown("right") then tx = tx - 250*dt end
end

-- Redefine love.draw to include the camera features
function love.draw()
	
	-- Apply the translation
	love.graphics.translate( math.floor(tx), math.floor(ty) )
	
	-- Set the draw range. Setting this will significantly increase drawing performance.
	map:autoDrawRange( math.floor(tx), math.floor(ty), 1, pad)
	
	-- Draw the map
	map:draw()
	
end
  
-- Save the tiles
local greenBush = map("Ground")(0,12)
local brownBush = map("Ground")(1,13)

-- Swap the tiles
map("Ground"):set(0,12, brownBush)
map("Ground"):set(1,13, greenBush)

-- Go through each tile and store the ones that have names
local tiles = {}
for id, tile in pairs(map.tiles) do
	if tile.properties.name then
		tiles[tile.properties.name] = tile
	end
end

-- Go through each tile and swap the brown and green bushes
for x, y, tile in map("Ground"):iterate() do
	if tile.properties.name == "Green Bush" then
		map("Ground"):set(x, y, tiles["Brown Bush"])
	elseif tile.properties.name == "Brown Bush" then
		map("Ground"):set(x, y, tiles["Green Bush"])
	end
end
